use microrm::prelude::*;

pub fn open_test_db_helper<DB: Schema>(identifier: &'static str) -> (microrm::ConnectionPool, DB) {
    let path = format!(
        "{tmpdir}/{identifier}.db",
        tmpdir = std::env!("CARGO_TARGET_TMPDIR"),
    );
    let path = path.replace("::", "_");
    let _ = std::fs::remove_file(path.as_str());
    let pool = microrm::ConnectionPool::new(path.as_str()).expect("couldn't connect to database");
    let db = DB::default();

    db.install(&mut pool.acquire().expect("couldn't acquire lease"))
        .expect("couldn't install schema");

    (pool, db)
}

mod macros {
    macro_rules! open_test_db {
        () => {{
            use stdext::function_name;
            $crate::common::open_test_db_helper(function_name!())
        }};
    }

    pub(crate) use open_test_db;
}

pub(crate) use macros::open_test_db;
